/***********************************************************************
 *                copyright 2004, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#include <stdio.h>
#include <localsys.h>
#include <cu_defs.h>
#include <X11/Xos.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

main(argc, argv) 
int argc;
char **argv;
{
	Display *d;
	char *dpy = NULL;
	char display[256];
	char *getenv();

	if (argc == 1) {
		dpy = getenv("DISPLAY");
		if (dpy == NULL) dpy = "";
		}
	else if (argc == 2)
		dpy = argv[1];

	display[0] = '\0';
	C_ARGSTR("-display",display,dpy,dpy,&argc,argv);

	if (strlen((char *)display) == 0) {
		fprintf(stderr,"usage: %s [displayname] or\n", argv[0]);
		fprintf(stderr,"    %s [-display displayname]\n", argv[0]);
		fprintf(stderr,"\nEnvironment variable DISPLAY is used if it is set\n");
		exit(1);
	}

	/* exit 0 if X display connect can be made, 1 otherwise */

	return ((d = XOpenDisplay(display)) == NULL);

}
